<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInitbfe762290f8f6a26d6c880a890bad315
{
    public static $files = array (
        '7b11c4dc42b3b3023073cb14e519683c' => __DIR__ . '/..' . '/ralouphie/getallheaders/src/getallheaders.php',
        'e3e111437f37e10e6bcab5eacc08fb6f' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/functions_include.php',
        '2bb094e40611cb5eccea789f32aff634' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/polyfill-mbstring/bootstrap.php',
        '1fd84176824b5a44e7bd8da85eca7e14' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/polyfill-php72/bootstrap.php',
        '606299e0d90ec13f1e6b53164b8387df' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/polyfill-intl-idn/bootstrap.php',
        '2d822e735b5b1897d96a7a28221d6513' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/deprecation-contracts/function.php',
        '6fe0d6ea1deb6acc74bbe64573a83e1c' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/functions_include.php',
        '3ed0dcebed83aa26dfe4c549d730cf2e' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/bootstrap.php',
    );

    public static $prefixLengthsPsr4 = array (
        'W' => 
        array (
            'WPMailSMTP\\' => 11,
        ),
        'C' => 
        array (
            'Composer\\Installers\\' => 20,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'WPMailSMTP\\' => 
        array (
            0 => __DIR__ . '/../..' . '/src',
        ),
        'Composer\\Installers\\' => 
        array (
            0 => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers',
        ),
    );

    public static $classMap = array (
        'Composer\\Installers\\AglInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/AglInstaller.php',
        'Composer\\Installers\\AimeosInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/AimeosInstaller.php',
        'Composer\\Installers\\AnnotateCmsInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/AnnotateCmsInstaller.php',
        'Composer\\Installers\\AsgardInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/AsgardInstaller.php',
        'Composer\\Installers\\AttogramInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/AttogramInstaller.php',
        'Composer\\Installers\\BaseInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/BaseInstaller.php',
        'Composer\\Installers\\BitrixInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/BitrixInstaller.php',
        'Composer\\Installers\\BonefishInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/BonefishInstaller.php',
        'Composer\\Installers\\CakePHPInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/CakePHPInstaller.php',
        'Composer\\Installers\\ChefInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/ChefInstaller.php',
        'Composer\\Installers\\CiviCrmInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/CiviCrmInstaller.php',
        'Composer\\Installers\\ClanCatsFrameworkInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/ClanCatsFrameworkInstaller.php',
        'Composer\\Installers\\CockpitInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/CockpitInstaller.php',
        'Composer\\Installers\\CodeIgniterInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/CodeIgniterInstaller.php',
        'Composer\\Installers\\Concrete5Installer' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/Concrete5Installer.php',
        'Composer\\Installers\\CraftInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/CraftInstaller.php',
        'Composer\\Installers\\CroogoInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/CroogoInstaller.php',
        'Composer\\Installers\\DecibelInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/DecibelInstaller.php',
        'Composer\\Installers\\DframeInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/DframeInstaller.php',
        'Composer\\Installers\\DokuWikiInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/DokuWikiInstaller.php',
        'Composer\\Installers\\DolibarrInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/DolibarrInstaller.php',
        'Composer\\Installers\\DrupalInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/DrupalInstaller.php',
        'Composer\\Installers\\ElggInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/ElggInstaller.php',
        'Composer\\Installers\\EliasisInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/EliasisInstaller.php',
        'Composer\\Installers\\ExpressionEngineInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/ExpressionEngineInstaller.php',
        'Composer\\Installers\\EzPlatformInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/EzPlatformInstaller.php',
        'Composer\\Installers\\FuelInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/FuelInstaller.php',
        'Composer\\Installers\\FuelphpInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/FuelphpInstaller.php',
        'Composer\\Installers\\GravInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/GravInstaller.php',
        'Composer\\Installers\\HuradInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/HuradInstaller.php',
        'Composer\\Installers\\ImageCMSInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/ImageCMSInstaller.php',
        'Composer\\Installers\\Installer' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/Installer.php',
        'Composer\\Installers\\ItopInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/ItopInstaller.php',
        'Composer\\Installers\\JoomlaInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/JoomlaInstaller.php',
        'Composer\\Installers\\KanboardInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/KanboardInstaller.php',
        'Composer\\Installers\\KirbyInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/KirbyInstaller.php',
        'Composer\\Installers\\KnownInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/KnownInstaller.php',
        'Composer\\Installers\\KodiCMSInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/KodiCMSInstaller.php',
        'Composer\\Installers\\KohanaInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/KohanaInstaller.php',
        'Composer\\Installers\\LanManagementSystemInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/LanManagementSystemInstaller.php',
        'Composer\\Installers\\LaravelInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/LaravelInstaller.php',
        'Composer\\Installers\\LavaLiteInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/LavaLiteInstaller.php',
        'Composer\\Installers\\LithiumInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/LithiumInstaller.php',
        'Composer\\Installers\\MODULEWorkInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/MODULEWorkInstaller.php',
        'Composer\\Installers\\MODXEvoInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/MODXEvoInstaller.php',
        'Composer\\Installers\\MagentoInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/MagentoInstaller.php',
        'Composer\\Installers\\MajimaInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/MajimaInstaller.php',
        'Composer\\Installers\\MakoInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/MakoInstaller.php',
        'Composer\\Installers\\MantisBTInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/MantisBTInstaller.php',
        'Composer\\Installers\\MauticInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/MauticInstaller.php',
        'Composer\\Installers\\MayaInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/MayaInstaller.php',
        'Composer\\Installers\\MediaWikiInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/MediaWikiInstaller.php',
        'Composer\\Installers\\MiaoxingInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/MiaoxingInstaller.php',
        'Composer\\Installers\\MicroweberInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/MicroweberInstaller.php',
        'Composer\\Installers\\ModxInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/ModxInstaller.php',
        'Composer\\Installers\\MoodleInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/MoodleInstaller.php',
        'Composer\\Installers\\OctoberInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/OctoberInstaller.php',
        'Composer\\Installers\\OntoWikiInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/OntoWikiInstaller.php',
        'Composer\\Installers\\OsclassInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/OsclassInstaller.php',
        'Composer\\Installers\\OxidInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/OxidInstaller.php',
        'Composer\\Installers\\PPIInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/PPIInstaller.php',
        'Composer\\Installers\\PantheonInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/PantheonInstaller.php',
        'Composer\\Installers\\PhiftyInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/PhiftyInstaller.php',
        'Composer\\Installers\\PhpBBInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/PhpBBInstaller.php',
        'Composer\\Installers\\PimcoreInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/PimcoreInstaller.php',
        'Composer\\Installers\\PiwikInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/PiwikInstaller.php',
        'Composer\\Installers\\PlentymarketsInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/PlentymarketsInstaller.php',
        'Composer\\Installers\\Plugin' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/Plugin.php',
        'Composer\\Installers\\PortoInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/PortoInstaller.php',
        'Composer\\Installers\\PrestashopInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/PrestashopInstaller.php',
        'Composer\\Installers\\ProcessWireInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/ProcessWireInstaller.php',
        'Composer\\Installers\\PuppetInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/PuppetInstaller.php',
        'Composer\\Installers\\PxcmsInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/PxcmsInstaller.php',
        'Composer\\Installers\\RadPHPInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/RadPHPInstaller.php',
        'Composer\\Installers\\ReIndexInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/ReIndexInstaller.php',
        'Composer\\Installers\\Redaxo5Installer' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/Redaxo5Installer.php',
        'Composer\\Installers\\RedaxoInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/RedaxoInstaller.php',
        'Composer\\Installers\\RoundcubeInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/RoundcubeInstaller.php',
        'Composer\\Installers\\SMFInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/SMFInstaller.php',
        'Composer\\Installers\\ShopwareInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/ShopwareInstaller.php',
        'Composer\\Installers\\SilverStripeInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/SilverStripeInstaller.php',
        'Composer\\Installers\\SiteDirectInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/SiteDirectInstaller.php',
        'Composer\\Installers\\StarbugInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/StarbugInstaller.php',
        'Composer\\Installers\\SyDESInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/SyDESInstaller.php',
        'Composer\\Installers\\SyliusInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/SyliusInstaller.php',
        'Composer\\Installers\\Symfony1Installer' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/Symfony1Installer.php',
        'Composer\\Installers\\TYPO3CmsInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/TYPO3CmsInstaller.php',
        'Composer\\Installers\\TYPO3FlowInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/TYPO3FlowInstaller.php',
        'Composer\\Installers\\TaoInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/TaoInstaller.php',
        'Composer\\Installers\\TastyIgniterInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/TastyIgniterInstaller.php',
        'Composer\\Installers\\TheliaInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/TheliaInstaller.php',
        'Composer\\Installers\\TuskInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/TuskInstaller.php',
        'Composer\\Installers\\UserFrostingInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/UserFrostingInstaller.php',
        'Composer\\Installers\\VanillaInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/VanillaInstaller.php',
        'Composer\\Installers\\VgmcpInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/VgmcpInstaller.php',
        'Composer\\Installers\\WHMCSInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/WHMCSInstaller.php',
        'Composer\\Installers\\WinterInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/WinterInstaller.php',
        'Composer\\Installers\\WolfCMSInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/WolfCMSInstaller.php',
        'Composer\\Installers\\WordPressInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/WordPressInstaller.php',
        'Composer\\Installers\\YawikInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/YawikInstaller.php',
        'Composer\\Installers\\ZendInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/ZendInstaller.php',
        'Composer\\Installers\\ZikulaInstaller' => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers/ZikulaInstaller.php',
        'WPMailSMTP\\AbstractConnection' => __DIR__ . '/../..' . '/src/AbstractConnection.php',
        'WPMailSMTP\\Admin\\AdminBarMenu' => __DIR__ . '/../..' . '/src/Admin/AdminBarMenu.php',
        'WPMailSMTP\\Admin\\Area' => __DIR__ . '/../..' . '/src/Admin/Area.php',
        'WPMailSMTP\\Admin\\ConnectionSettings' => __DIR__ . '/../..' . '/src/Admin/ConnectionSettings.php',
        'WPMailSMTP\\Admin\\DashboardWidget' => __DIR__ . '/../..' . '/src/Admin/DashboardWidget.php',
        'WPMailSMTP\\Admin\\DebugEvents\\DebugEvents' => __DIR__ . '/../..' . '/src/Admin/DebugEvents/DebugEvents.php',
        'WPMailSMTP\\Admin\\DebugEvents\\Event' => __DIR__ . '/../..' . '/src/Admin/DebugEvents/Event.php',
        'WPMailSMTP\\Admin\\DebugEvents\\EventsCollection' => __DIR__ . '/../..' . '/src/Admin/DebugEvents/EventsCollection.php',
        'WPMailSMTP\\Admin\\DebugEvents\\Migration' => __DIR__ . '/../..' . '/src/Admin/DebugEvents/Migration.php',
        'WPMailSMTP\\Admin\\DebugEvents\\Table' => __DIR__ . '/../..' . '/src/Admin/DebugEvents/Table.php',
        'WPMailSMTP\\Admin\\DomainChecker' => __DIR__ . '/../..' . '/src/Admin/DomainChecker.php',
        'WPMailSMTP\\Admin\\Education' => __DIR__ . '/../..' . '/src/Admin/Education.php',
        'WPMailSMTP\\Admin\\FlyoutMenu' => __DIR__ . '/../..' . '/src/Admin/FlyoutMenu.php',
        'WPMailSMTP\\Admin\\Notifications' => __DIR__ . '/../..' . '/src/Admin/Notifications.php',
        'WPMailSMTP\\Admin\\PageAbstract' => __DIR__ . '/../..' . '/src/Admin/PageAbstract.php',
        'WPMailSMTP\\Admin\\PageInterface' => __DIR__ . '/../..' . '/src/Admin/PageInterface.php',
        'WPMailSMTP\\Admin\\Pages\\About' => __DIR__ . '/../..' . '/src/Admin/Pages/About.php',
        'WPMailSMTP\\Admin\\Pages\\AboutTab' => __DIR__ . '/../..' . '/src/Admin/Pages/AboutTab.php',
        'WPMailSMTP\\Admin\\Pages\\ActionSchedulerTab' => __DIR__ . '/../..' . '/src/Admin/Pages/ActionSchedulerTab.php',
        'WPMailSMTP\\Admin\\Pages\\AdditionalConnectionsTab' => __DIR__ . '/../..' . '/src/Admin/Pages/AdditionalConnectionsTab.php',
        'WPMailSMTP\\Admin\\Pages\\AlertsTab' => __DIR__ . '/../..' . '/src/Admin/Pages/AlertsTab.php',
        'WPMailSMTP\\Admin\\Pages\\AuthTab' => __DIR__ . '/../..' . '/src/Admin/Pages/AuthTab.php',
        'WPMailSMTP\\Admin\\Pages\\ControlTab' => __DIR__ . '/../..' . '/src/Admin/Pages/ControlTab.php',
        'WPMailSMTP\\Admin\\Pages\\DebugEventsTab' => __DIR__ . '/../..' . '/src/Admin/Pages/DebugEventsTab.php',
        'WPMailSMTP\\Admin\\Pages\\EmailReports' => __DIR__ . '/../..' . '/src/Admin/Pages/EmailReports.php',
        'WPMailSMTP\\Admin\\Pages\\EmailReportsTab' => __DIR__ . '/../..' . '/src/Admin/Pages/EmailReportsTab.php',
        'WPMailSMTP\\Admin\\Pages\\ExportTab' => __DIR__ . '/../..' . '/src/Admin/Pages/ExportTab.php',
        'WPMailSMTP\\Admin\\Pages\\Logs' => __DIR__ . '/../..' . '/src/Admin/Pages/Logs.php',
        'WPMailSMTP\\Admin\\Pages\\LogsTab' => __DIR__ . '/../..' . '/src/Admin/Pages/LogsTab.php',
        'WPMailSMTP\\Admin\\Pages\\MiscTab' => __DIR__ . '/../..' . '/src/Admin/Pages/MiscTab.php',
        'WPMailSMTP\\Admin\\Pages\\SettingsTab' => __DIR__ . '/../..' . '/src/Admin/Pages/SettingsTab.php',
        'WPMailSMTP\\Admin\\Pages\\SmartRoutingTab' => __DIR__ . '/../..' . '/src/Admin/Pages/SmartRoutingTab.php',
        'WPMailSMTP\\Admin\\Pages\\TestTab' => __DIR__ . '/../..' . '/src/Admin/Pages/TestTab.php',
        'WPMailSMTP\\Admin\\Pages\\Tools' => __DIR__ . '/../..' . '/src/Admin/Pages/Tools.php',
        'WPMailSMTP\\Admin\\Pages\\VersusTab' => __DIR__ . '/../..' . '/src/Admin/Pages/VersusTab.php',
        'WPMailSMTP\\Admin\\ParentPageAbstract' => __DIR__ . '/../..' . '/src/Admin/ParentPageAbstract.php',
        'WPMailSMTP\\Admin\\PluginsInstallSkin' => __DIR__ . '/../..' . '/src/Admin/PluginsInstallSkin.php',
        'WPMailSMTP\\Admin\\PluginsInstallUpgrader' => __DIR__ . '/../..' . '/src/Admin/PluginsInstallUpgrader.php',
        'WPMailSMTP\\Admin\\Review' => __DIR__ . '/../..' . '/src/Admin/Review.php',
        'WPMailSMTP\\Admin\\SetupWizard' => __DIR__ . '/../..' . '/src/Admin/SetupWizard.php',
        'WPMailSMTP\\Compatibility\\Compatibility' => __DIR__ . '/../..' . '/src/Compatibility/Compatibility.php',
        'WPMailSMTP\\Compatibility\\Plugin\\Admin2020' => __DIR__ . '/../..' . '/src/Compatibility/Plugin/Admin2020.php',
        'WPMailSMTP\\Compatibility\\Plugin\\PluginAbstract' => __DIR__ . '/../..' . '/src/Compatibility/Plugin/PluginAbstract.php',
        'WPMailSMTP\\Compatibility\\Plugin\\PluginInterface' => __DIR__ . '/../..' . '/src/Compatibility/Plugin/PluginInterface.php',
        'WPMailSMTP\\Conflicts' => __DIR__ . '/../..' . '/src/Conflicts.php',
        'WPMailSMTP\\Connect' => __DIR__ . '/../..' . '/src/Connect.php',
        'WPMailSMTP\\Connection' => __DIR__ . '/../..' . '/src/Connection.php',
        'WPMailSMTP\\ConnectionInterface' => __DIR__ . '/../..' . '/src/ConnectionInterface.php',
        'WPMailSMTP\\ConnectionsManager' => __DIR__ . '/../..' . '/src/ConnectionsManager.php',
        'WPMailSMTP\\Core' => __DIR__ . '/../..' . '/src/Core.php',
        'WPMailSMTP\\DBRepair' => __DIR__ . '/../..' . '/src/DBRepair.php',
        'WPMailSMTP\\Debug' => __DIR__ . '/../..' . '/src/Debug.php',
        'WPMailSMTP\\Geo' => __DIR__ . '/../..' . '/src/Geo.php',
        'WPMailSMTP\\Helpers\\Crypto' => __DIR__ . '/../..' . '/src/Helpers/Crypto.php',
        'WPMailSMTP\\Helpers\\DB' => __DIR__ . '/../..' . '/src/Helpers/DB.php',
        'WPMailSMTP\\Helpers\\Helpers' => __DIR__ . '/../..' . '/src/Helpers/Helpers.php',
        'WPMailSMTP\\Helpers\\PluginImportDataRetriever' => __DIR__ . '/../..' . '/src/Helpers/PluginImportDataRetriever.php',
        'WPMailSMTP\\MailCatcher' => __DIR__ . '/../..' . '/src/MailCatcher.php',
        'WPMailSMTP\\MailCatcherInterface' => __DIR__ . '/../..' . '/src/MailCatcherInterface.php',
        'WPMailSMTP\\MailCatcherTrait' => __DIR__ . '/../..' . '/src/MailCatcherTrait.php',
        'WPMailSMTP\\MailCatcherV6' => __DIR__ . '/../..' . '/src/MailCatcherV6.php',
        'WPMailSMTP\\Migration' => __DIR__ . '/../..' . '/src/Migration.php',
        'WPMailSMTP\\MigrationAbstract' => __DIR__ . '/../..' . '/src/MigrationAbstract.php',
        'WPMailSMTP\\Options' => __DIR__ . '/../..' . '/src/Options.php',
        'WPMailSMTP\\Pro\\AdditionalConnections\\AdditionalConnections' => __DIR__ . '/../..' . '/src/Pro/AdditionalConnections/AdditionalConnections.php',
        'WPMailSMTP\\Pro\\AdditionalConnections\\Admin\\SettingsTab' => __DIR__ . '/../..' . '/src/Pro/AdditionalConnections/Admin/SettingsTab.php',
        'WPMailSMTP\\Pro\\AdditionalConnections\\Admin\\TestTab' => __DIR__ . '/../..' . '/src/Pro/AdditionalConnections/Admin/TestTab.php',
        'WPMailSMTP\\Pro\\AdditionalConnections\\Connection' => __DIR__ . '/../..' . '/src/Pro/AdditionalConnections/Connection.php',
        'WPMailSMTP\\Pro\\AdditionalConnections\\ConnectionOptions' => __DIR__ . '/../..' . '/src/Pro/AdditionalConnections/ConnectionOptions.php',
        'WPMailSMTP\\Pro\\Admin\\DashboardWidget' => __DIR__ . '/../..' . '/src/Pro/Admin/DashboardWidget.php',
        'WPMailSMTP\\Pro\\Admin\\PluginsList' => __DIR__ . '/../..' . '/src/Pro/Admin/PluginsList.php',
        'WPMailSMTP\\Pro\\Alerts\\AbstractOptions' => __DIR__ . '/../..' . '/src/Pro/Alerts/AbstractOptions.php',
        'WPMailSMTP\\Pro\\Alerts\\Admin\\SettingsTab' => __DIR__ . '/../..' . '/src/Pro/Alerts/Admin/SettingsTab.php',
        'WPMailSMTP\\Pro\\Alerts\\Alert' => __DIR__ . '/../..' . '/src/Pro/Alerts/Alert.php',
        'WPMailSMTP\\Pro\\Alerts\\Alerts' => __DIR__ . '/../..' . '/src/Pro/Alerts/Alerts.php',
        'WPMailSMTP\\Pro\\Alerts\\Handlers\\HandlerInterface' => __DIR__ . '/../..' . '/src/Pro/Alerts/Handlers/HandlerInterface.php',
        'WPMailSMTP\\Pro\\Alerts\\Loader' => __DIR__ . '/../..' . '/src/Pro/Alerts/Loader.php',
        'WPMailSMTP\\Pro\\Alerts\\Notifier' => __DIR__ . '/../..' . '/src/Pro/Alerts/Notifier.php',
        'WPMailSMTP\\Pro\\Alerts\\OptionsInterface' => __DIR__ . '/../..' . '/src/Pro/Alerts/OptionsInterface.php',
        'WPMailSMTP\\Pro\\Alerts\\Providers\\CustomWebhook\\Handler' => __DIR__ . '/../..' . '/src/Pro/Alerts/Providers/CustomWebhook/Handler.php',
        'WPMailSMTP\\Pro\\Alerts\\Providers\\CustomWebhook\\Options' => __DIR__ . '/../..' . '/src/Pro/Alerts/Providers/CustomWebhook/Options.php',
        'WPMailSMTP\\Pro\\Alerts\\Providers\\Email\\Handler' => __DIR__ . '/../..' . '/src/Pro/Alerts/Providers/Email/Handler.php',
        'WPMailSMTP\\Pro\\Alerts\\Providers\\Email\\Options' => __DIR__ . '/../..' . '/src/Pro/Alerts/Providers/Email/Options.php',
        'WPMailSMTP\\Pro\\Alerts\\Providers\\SlackWebhook\\Handler' => __DIR__ . '/../..' . '/src/Pro/Alerts/Providers/SlackWebhook/Handler.php',
        'WPMailSMTP\\Pro\\Alerts\\Providers\\SlackWebhook\\Options' => __DIR__ . '/../..' . '/src/Pro/Alerts/Providers/SlackWebhook/Options.php',
        'WPMailSMTP\\Pro\\Alerts\\Providers\\TwilioSMS\\Handler' => __DIR__ . '/../..' . '/src/Pro/Alerts/Providers/TwilioSMS/Handler.php',
        'WPMailSMTP\\Pro\\Alerts\\Providers\\TwilioSMS\\Options' => __DIR__ . '/../..' . '/src/Pro/Alerts/Providers/TwilioSMS/Options.php',
        'WPMailSMTP\\Pro\\BackupConnections\\Admin\\SettingsTab' => __DIR__ . '/../..' . '/src/Pro/BackupConnections/Admin/SettingsTab.php',
        'WPMailSMTP\\Pro\\BackupConnections\\BackupConnections' => __DIR__ . '/../..' . '/src/Pro/BackupConnections/BackupConnections.php',
        'WPMailSMTP\\Pro\\ConditionalLogic\\CanProcessConditionalLogicTrait' => __DIR__ . '/../..' . '/src/Pro/ConditionalLogic/CanProcessConditionalLogicTrait.php',
        'WPMailSMTP\\Pro\\ConditionalLogic\\ConditionalLogicSettings' => __DIR__ . '/../..' . '/src/Pro/ConditionalLogic/ConditionalLogicSettings.php',
        'WPMailSMTP\\Pro\\ConnectionsManager' => __DIR__ . '/../..' . '/src/Pro/ConnectionsManager.php',
        'WPMailSMTP\\Pro\\DBRepair' => __DIR__ . '/../..' . '/src/Pro/DBRepair.php',
        'WPMailSMTP\\Pro\\Emails\\Control\\Admin\\SettingsTab' => __DIR__ . '/../..' . '/src/Pro/Emails/Control/Admin/SettingsTab.php',
        'WPMailSMTP\\Pro\\Emails\\Control\\Control' => __DIR__ . '/../..' . '/src/Pro/Emails/Control/Control.php',
        'WPMailSMTP\\Pro\\Emails\\Control\\Reload' => __DIR__ . '/../..' . '/src/Pro/Emails/Control/Reload.php',
        'WPMailSMTP\\Pro\\Emails\\Control\\Switcher' => __DIR__ . '/../..' . '/src/Pro/Emails/Control/Switcher.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Admin\\ArchivePage' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Admin/ArchivePage.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Admin\\PageAbstract' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Admin/PageAbstract.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Admin\\PrintPreview' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Admin/PrintPreview.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Admin\\SettingsTab' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Admin/SettingsTab.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Admin\\SinglePage' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Admin/SinglePage.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Admin\\Table' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Admin/Table.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Attachments\\Attachment' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Attachments/Attachment.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Attachments\\Attachments' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Attachments/Attachments.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Attachments\\Cleanup' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Attachments/Cleanup.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Attachments\\Migration' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Attachments/Migration.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\CanResendEmailTrait' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/CanResendEmailTrait.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Email' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Email.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\EmailsCollection' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/EmailsCollection.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Export\\AbstractData' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Export/AbstractData.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Export\\Admin' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Export/Admin.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Export\\CanRemoveExportFileTrait' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Export/CanRemoveExportFileTrait.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Export\\EMLData' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Export/EMLData.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Export\\Export' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Export/Export.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Export\\File' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Export/File.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Export\\Handler' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Export/Handler.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Export\\Request' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Export/Request.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Export\\TableData' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Export/TableData.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Importers\\ImporterAbstract' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Importers/ImporterAbstract.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Importers\\ImporterInterface' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Importers/ImporterInterface.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Importers\\ImporterTabAbstract' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Importers/ImporterTabAbstract.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Importers\\ImporterTabAbstractInterface' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Importers/ImporterTabAbstractInterface.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Importers\\Importers' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Importers/Importers.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Importers\\WPMailLogging\\Importer' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Importers/WPMailLogging/Importer.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Importers\\WPMailLogging\\Tab' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Importers/WPMailLogging/Tab.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Logs' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Logs.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Migration' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Migration.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Providers\\Common' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Providers/Common.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Providers\\SMTP' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Providers/SMTP.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Reports\\Admin' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Reports/Admin.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Reports\\Emails\\Summary' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Reports/Emails/Summary.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Reports\\Report' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Reports/Report.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Reports\\Reports' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Reports/Reports.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Reports\\Table' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Reports/Table.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Resend' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Resend.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Tracking\\Cleanup' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Tracking/Cleanup.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Tracking\\Events\\AbstractEvent' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Tracking/Events/AbstractEvent.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Tracking\\Events\\EventFactory' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Tracking/Events/EventFactory.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Tracking\\Events\\EventInterface' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Tracking/Events/EventInterface.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Tracking\\Events\\Events' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Tracking/Events/Events.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Tracking\\Events\\Injectable\\AbstractInjectableEvent' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Tracking/Events/Injectable/AbstractInjectableEvent.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Tracking\\Events\\Injectable\\ClickLinkEvent' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Tracking/Events/Injectable/ClickLinkEvent.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Tracking\\Events\\Injectable\\OpenEmailEvent' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Tracking/Events/Injectable/OpenEmailEvent.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Tracking\\Migration' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Tracking/Migration.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Tracking\\Tracking' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Tracking/Tracking.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\AbstractProcessor' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/AbstractProcessor.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\AbstractProvider' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/AbstractProvider.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\AbstractSubscriber' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/AbstractSubscriber.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Events\\Delivered' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Events/Delivered.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Events\\EventInterface' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Events/EventInterface.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Events\\Failed' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Events/Failed.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\ProcessorInterface' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/ProcessorInterface.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\ProviderInterface' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/ProviderInterface.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Mailgun\\Events\\Failed' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Mailgun/Events/Failed.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Mailgun\\Processor' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Mailgun/Processor.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Mailgun\\Provider' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Mailgun/Provider.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Mailgun\\Subscriber' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Mailgun/Subscriber.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Postmark\\Events\\Failed' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Postmark/Events/Failed.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Postmark\\Processor' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Postmark/Processor.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Postmark\\Provider' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Postmark/Provider.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Postmark\\Subscriber' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Postmark/Subscriber.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\SMTPcom\\Events\\Failed' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/SMTPcom/Events/Failed.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\SMTPcom\\Processor' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/SMTPcom/Processor.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\SMTPcom\\Provider' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/SMTPcom/Provider.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\SMTPcom\\Subscriber' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/SMTPcom/Subscriber.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Sendinblue\\Events\\Failed' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Sendinblue/Events/Failed.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Sendinblue\\Processor' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Sendinblue/Processor.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Sendinblue\\Provider' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Sendinblue/Provider.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Sendinblue\\Subscriber' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Sendinblue/Subscriber.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Sendlayer\\Events\\Failed' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Sendlayer/Events/Failed.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Sendlayer\\Processor' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Sendlayer/Processor.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Sendlayer\\Provider' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Sendlayer/Provider.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\Sendlayer\\Subscriber' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/Sendlayer/Subscriber.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\SparkPost\\Events\\Failed' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/SparkPost/Events/Failed.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\SparkPost\\Processor' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/SparkPost/Processor.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\SparkPost\\Provider' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/SparkPost/Provider.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Providers\\SparkPost\\Subscriber' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Providers/SparkPost/Subscriber.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\SubscriberInterface' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/SubscriberInterface.php',
        'WPMailSMTP\\Pro\\Emails\\Logs\\Webhooks\\Webhooks' => __DIR__ . '/../..' . '/src/Pro/Emails/Logs/Webhooks/Webhooks.php',
        'WPMailSMTP\\Pro\\License\\License' => __DIR__ . '/../..' . '/src/Pro/License/License.php',
        'WPMailSMTP\\Pro\\License\\Updater' => __DIR__ . '/../..' . '/src/Pro/License/Updater.php',
        'WPMailSMTP\\Pro\\MailCatcher' => __DIR__ . '/../..' . '/src/Pro/MailCatcher.php',
        'WPMailSMTP\\Pro\\MailCatcherTrait' => __DIR__ . '/../..' . '/src/Pro/MailCatcherTrait.php',
        'WPMailSMTP\\Pro\\MailCatcherV6' => __DIR__ . '/../..' . '/src/Pro/MailCatcherV6.php',
        'WPMailSMTP\\Pro\\Migration' => __DIR__ . '/../..' . '/src/Pro/Migration.php',
        'WPMailSMTP\\Pro\\Multisite' => __DIR__ . '/../..' . '/src/Pro/Multisite.php',
        'WPMailSMTP\\Pro\\Pro' => __DIR__ . '/../..' . '/src/Pro/Pro.php',
        'WPMailSMTP\\Pro\\Providers\\AmazonSES\\Auth' => __DIR__ . '/../..' . '/src/Pro/Providers/AmazonSES/Auth.php',
        'WPMailSMTP\\Pro\\Providers\\AmazonSES\\IdentitiesTable' => __DIR__ . '/../..' . '/src/Pro/Providers/AmazonSES/IdentitiesTable.php',
        'WPMailSMTP\\Pro\\Providers\\AmazonSES\\Identity' => __DIR__ . '/../..' . '/src/Pro/Providers/AmazonSES/Identity.php',
        'WPMailSMTP\\Pro\\Providers\\AmazonSES\\Mailer' => __DIR__ . '/../..' . '/src/Pro/Providers/AmazonSES/Mailer.php',
        'WPMailSMTP\\Pro\\Providers\\AmazonSES\\Options' => __DIR__ . '/../..' . '/src/Pro/Providers/AmazonSES/Options.php',
        'WPMailSMTP\\Pro\\Providers\\Outlook\\AttachmentsUploader' => __DIR__ . '/../..' . '/src/Pro/Providers/Outlook/AttachmentsUploader.php',
        'WPMailSMTP\\Pro\\Providers\\Outlook\\Auth' => __DIR__ . '/../..' . '/src/Pro/Providers/Outlook/Auth.php',
        'WPMailSMTP\\Pro\\Providers\\Outlook\\Mailer' => __DIR__ . '/../..' . '/src/Pro/Providers/Outlook/Mailer.php',
        'WPMailSMTP\\Pro\\Providers\\Outlook\\Options' => __DIR__ . '/../..' . '/src/Pro/Providers/Outlook/Options.php',
        'WPMailSMTP\\Pro\\Providers\\Providers' => __DIR__ . '/../..' . '/src/Pro/Providers/Providers.php',
        'WPMailSMTP\\Pro\\Providers\\Zoho\\Auth' => __DIR__ . '/../..' . '/src/Pro/Providers/Zoho/Auth.php',
        'WPMailSMTP\\Pro\\Providers\\Zoho\\Auth\\Zoho' => __DIR__ . '/../..' . '/src/Pro/Providers/Zoho/Auth/Zoho.php',
        'WPMailSMTP\\Pro\\Providers\\Zoho\\Auth\\ZohoUser' => __DIR__ . '/../..' . '/src/Pro/Providers/Zoho/Auth/ZohoUser.php',
        'WPMailSMTP\\Pro\\Providers\\Zoho\\Mailer' => __DIR__ . '/../..' . '/src/Pro/Providers/Zoho/Mailer.php',
        'WPMailSMTP\\Pro\\Providers\\Zoho\\Options' => __DIR__ . '/../..' . '/src/Pro/Providers/Zoho/Options.php',
        'WPMailSMTP\\Pro\\SiteHealth' => __DIR__ . '/../..' . '/src/Pro/SiteHealth.php',
        'WPMailSMTP\\Pro\\SmartRouting\\Admin\\SettingsTab' => __DIR__ . '/../..' . '/src/Pro/SmartRouting/Admin/SettingsTab.php',
        'WPMailSMTP\\Pro\\SmartRouting\\ConditionalLogic' => __DIR__ . '/../..' . '/src/Pro/SmartRouting/ConditionalLogic.php',
        'WPMailSMTP\\Pro\\SmartRouting\\SmartRouting' => __DIR__ . '/../..' . '/src/Pro/SmartRouting/SmartRouting.php',
        'WPMailSMTP\\Pro\\Tasks\\EmailLogCleanupTask' => __DIR__ . '/../..' . '/src/Pro/Tasks/EmailLogCleanupTask.php',
        'WPMailSMTP\\Pro\\Tasks\\Logs\\ExportCleanupTask' => __DIR__ . '/../..' . '/src/Pro/Tasks/Logs/ExportCleanupTask.php',
        'WPMailSMTP\\Pro\\Tasks\\Logs\\Mailgun\\VerifySentStatusTask' => __DIR__ . '/../..' . '/src/Pro/Tasks/Logs/Mailgun/VerifySentStatusTask.php',
        'WPMailSMTP\\Pro\\Tasks\\Logs\\Postmark\\VerifySentStatusTask' => __DIR__ . '/../..' . '/src/Pro/Tasks/Logs/Postmark/VerifySentStatusTask.php',
        'WPMailSMTP\\Pro\\Tasks\\Logs\\ResendTask' => __DIR__ . '/../..' . '/src/Pro/Tasks/Logs/ResendTask.php',
        'WPMailSMTP\\Pro\\Tasks\\Logs\\SMTPcom\\VerifySentStatusTask' => __DIR__ . '/../..' . '/src/Pro/Tasks/Logs/SMTPcom/VerifySentStatusTask.php',
        'WPMailSMTP\\Pro\\Tasks\\Logs\\Sendinblue\\VerifySentStatusTask' => __DIR__ . '/../..' . '/src/Pro/Tasks/Logs/Sendinblue/VerifySentStatusTask.php',
        'WPMailSMTP\\Pro\\Tasks\\Logs\\Sendlayer\\VerifySentStatusTask' => __DIR__ . '/../..' . '/src/Pro/Tasks/Logs/Sendlayer/VerifySentStatusTask.php',
        'WPMailSMTP\\Pro\\Tasks\\Logs\\SparkPost\\VerifySentStatusTask' => __DIR__ . '/../..' . '/src/Pro/Tasks/Logs/SparkPost/VerifySentStatusTask.php',
        'WPMailSMTP\\Pro\\Tasks\\Logs\\VerifySentStatusTaskAbstract' => __DIR__ . '/../..' . '/src/Pro/Tasks/Logs/VerifySentStatusTaskAbstract.php',
        'WPMailSMTP\\Pro\\Tasks\\Migrations\\EmailLogMigration11' => __DIR__ . '/../..' . '/src/Pro/Tasks/Migrations/EmailLogMigration11.php',
        'WPMailSMTP\\Pro\\Tasks\\Migrations\\EmailLogMigration4' => __DIR__ . '/../..' . '/src/Pro/Tasks/Migrations/EmailLogMigration4.php',
        'WPMailSMTP\\Pro\\Tasks\\Migrations\\EmailLogMigration5' => __DIR__ . '/../..' . '/src/Pro/Tasks/Migrations/EmailLogMigration5.php',
        'WPMailSMTP\\Pro\\Tasks\\NotifierTask' => __DIR__ . '/../..' . '/src/Pro/Tasks/NotifierTask.php',
        'WPMailSMTP\\Pro\\WPMailArgs' => __DIR__ . '/../..' . '/src/Pro/WPMailArgs.php',
        'WPMailSMTP\\Processor' => __DIR__ . '/../..' . '/src/Processor.php',
        'WPMailSMTP\\Providers\\AmazonSES\\Options' => __DIR__ . '/../..' . '/src/Providers/AmazonSES/Options.php',
        'WPMailSMTP\\Providers\\AuthAbstract' => __DIR__ . '/../..' . '/src/Providers/AuthAbstract.php',
        'WPMailSMTP\\Providers\\AuthInterface' => __DIR__ . '/../..' . '/src/Providers/AuthInterface.php',
        'WPMailSMTP\\Providers\\Gmail\\Auth' => __DIR__ . '/../..' . '/src/Providers/Gmail/Auth.php',
        'WPMailSMTP\\Providers\\Gmail\\Mailer' => __DIR__ . '/../..' . '/src/Providers/Gmail/Mailer.php',
        'WPMailSMTP\\Providers\\Gmail\\Options' => __DIR__ . '/../..' . '/src/Providers/Gmail/Options.php',
        'WPMailSMTP\\Providers\\Loader' => __DIR__ . '/../..' . '/src/Providers/Loader.php',
        'WPMailSMTP\\Providers\\Mail\\Mailer' => __DIR__ . '/../..' . '/src/Providers/Mail/Mailer.php',
        'WPMailSMTP\\Providers\\Mail\\Options' => __DIR__ . '/../..' . '/src/Providers/Mail/Options.php',
        'WPMailSMTP\\Providers\\MailerAbstract' => __DIR__ . '/../..' . '/src/Providers/MailerAbstract.php',
        'WPMailSMTP\\Providers\\MailerInterface' => __DIR__ . '/../..' . '/src/Providers/MailerInterface.php',
        'WPMailSMTP\\Providers\\Mailgun\\Mailer' => __DIR__ . '/../..' . '/src/Providers/Mailgun/Mailer.php',
        'WPMailSMTP\\Providers\\Mailgun\\Options' => __DIR__ . '/../..' . '/src/Providers/Mailgun/Options.php',
        'WPMailSMTP\\Providers\\OptionsAbstract' => __DIR__ . '/../..' . '/src/Providers/OptionsAbstract.php',
        'WPMailSMTP\\Providers\\OptionsInterface' => __DIR__ . '/../..' . '/src/Providers/OptionsInterface.php',
        'WPMailSMTP\\Providers\\Outlook\\Options' => __DIR__ . '/../..' . '/src/Providers/Outlook/Options.php',
        'WPMailSMTP\\Providers\\PepipostAPI\\Mailer' => __DIR__ . '/../..' . '/src/Providers/PepipostAPI/Mailer.php',
        'WPMailSMTP\\Providers\\PepipostAPI\\Options' => __DIR__ . '/../..' . '/src/Providers/PepipostAPI/Options.php',
        'WPMailSMTP\\Providers\\Pepipost\\Mailer' => __DIR__ . '/../..' . '/src/Providers/Pepipost/Mailer.php',
        'WPMailSMTP\\Providers\\Pepipost\\Options' => __DIR__ . '/../..' . '/src/Providers/Pepipost/Options.php',
        'WPMailSMTP\\Providers\\Postmark\\Mailer' => __DIR__ . '/../..' . '/src/Providers/Postmark/Mailer.php',
        'WPMailSMTP\\Providers\\Postmark\\Options' => __DIR__ . '/../..' . '/src/Providers/Postmark/Options.php',
        'WPMailSMTP\\Providers\\SMTP\\Mailer' => __DIR__ . '/../..' . '/src/Providers/SMTP/Mailer.php',
        'WPMailSMTP\\Providers\\SMTP\\Options' => __DIR__ . '/../..' . '/src/Providers/SMTP/Options.php',
        'WPMailSMTP\\Providers\\SMTPcom\\Mailer' => __DIR__ . '/../..' . '/src/Providers/SMTPcom/Mailer.php',
        'WPMailSMTP\\Providers\\SMTPcom\\Options' => __DIR__ . '/../..' . '/src/Providers/SMTPcom/Options.php',
        'WPMailSMTP\\Providers\\Sendgrid\\Mailer' => __DIR__ . '/../..' . '/src/Providers/Sendgrid/Mailer.php',
        'WPMailSMTP\\Providers\\Sendgrid\\Options' => __DIR__ . '/../..' . '/src/Providers/Sendgrid/Options.php',
        'WPMailSMTP\\Providers\\Sendinblue\\Api' => __DIR__ . '/../..' . '/src/Providers/Sendinblue/Api.php',
        'WPMailSMTP\\Providers\\Sendinblue\\Mailer' => __DIR__ . '/../..' . '/src/Providers/Sendinblue/Mailer.php',
        'WPMailSMTP\\Providers\\Sendinblue\\Options' => __DIR__ . '/../..' . '/src/Providers/Sendinblue/Options.php',
        'WPMailSMTP\\Providers\\Sendlayer\\Mailer' => __DIR__ . '/../..' . '/src/Providers/Sendlayer/Mailer.php',
        'WPMailSMTP\\Providers\\Sendlayer\\Options' => __DIR__ . '/../..' . '/src/Providers/Sendlayer/Options.php',
        'WPMailSMTP\\Providers\\SparkPost\\Mailer' => __DIR__ . '/../..' . '/src/Providers/SparkPost/Mailer.php',
        'WPMailSMTP\\Providers\\SparkPost\\Options' => __DIR__ . '/../..' . '/src/Providers/SparkPost/Options.php',
        'WPMailSMTP\\Providers\\Zoho\\Options' => __DIR__ . '/../..' . '/src/Providers/Zoho/Options.php',
        'WPMailSMTP\\Reports\\Emails\\Summary' => __DIR__ . '/../..' . '/src/Reports/Emails/Summary.php',
        'WPMailSMTP\\Reports\\Reports' => __DIR__ . '/../..' . '/src/Reports/Reports.php',
        'WPMailSMTP\\SiteHealth' => __DIR__ . '/../..' . '/src/SiteHealth.php',
        'WPMailSMTP\\Tasks\\DebugEventsCleanupTask' => __DIR__ . '/../..' . '/src/Tasks/DebugEventsCleanupTask.php',
        'WPMailSMTP\\Tasks\\Meta' => __DIR__ . '/../..' . '/src/Tasks/Meta.php',
        'WPMailSMTP\\Tasks\\Reports\\SummaryEmailTask' => __DIR__ . '/../..' . '/src/Tasks/Reports/SummaryEmailTask.php',
        'WPMailSMTP\\Tasks\\Task' => __DIR__ . '/../..' . '/src/Tasks/Task.php',
        'WPMailSMTP\\Tasks\\Tasks' => __DIR__ . '/../..' . '/src/Tasks/Tasks.php',
        'WPMailSMTP\\Upgrade' => __DIR__ . '/../..' . '/src/Upgrade.php',
        'WPMailSMTP\\Uploads' => __DIR__ . '/../..' . '/src/Uploads.php',
        'WPMailSMTP\\UsageTracking\\SendUsageTask' => __DIR__ . '/../..' . '/src/UsageTracking/SendUsageTask.php',
        'WPMailSMTP\\UsageTracking\\UsageTracking' => __DIR__ . '/../..' . '/src/UsageTracking/UsageTracking.php',
        'WPMailSMTP\\Vendor\\Google\\AccessToken\\Revoke' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/AccessToken/Revoke.php',
        'WPMailSMTP\\Vendor\\Google\\AccessToken\\Verify' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/AccessToken/Verify.php',
        'WPMailSMTP\\Vendor\\Google\\AuthHandler\\AuthHandlerFactory' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/AuthHandler/AuthHandlerFactory.php',
        'WPMailSMTP\\Vendor\\Google\\AuthHandler\\Guzzle5AuthHandler' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/AuthHandler/Guzzle5AuthHandler.php',
        'WPMailSMTP\\Vendor\\Google\\AuthHandler\\Guzzle6AuthHandler' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/AuthHandler/Guzzle6AuthHandler.php',
        'WPMailSMTP\\Vendor\\Google\\AuthHandler\\Guzzle7AuthHandler' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/AuthHandler/Guzzle7AuthHandler.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\AccessToken' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/AccessToken.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\ApplicationDefaultCredentials' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/ApplicationDefaultCredentials.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\CacheTrait' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/CacheTrait.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Cache\\InvalidArgumentException' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Cache/InvalidArgumentException.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Cache\\Item' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Cache/Item.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Cache\\MemoryCacheItemPool' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Cache/MemoryCacheItemPool.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Cache\\SysVCacheItemPool' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Cache/SysVCacheItemPool.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Cache\\TypedItem' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Cache/TypedItem.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\CredentialsLoader' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/CredentialsLoader.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Credentials\\AppIdentityCredentials' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Credentials/AppIdentityCredentials.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Credentials\\GCECredentials' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Credentials/GCECredentials.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Credentials\\IAMCredentials' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Credentials/IAMCredentials.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Credentials\\ImpersonatedServiceAccountCredentials' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Credentials/ImpersonatedServiceAccountCredentials.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Credentials\\InsecureCredentials' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Credentials/InsecureCredentials.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Credentials\\ServiceAccountCredentials' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Credentials/ServiceAccountCredentials.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Credentials\\ServiceAccountJwtAccessCredentials' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Credentials/ServiceAccountJwtAccessCredentials.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Credentials\\UserRefreshCredentials' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Credentials/UserRefreshCredentials.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\FetchAuthTokenCache' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/FetchAuthTokenCache.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\FetchAuthTokenInterface' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/FetchAuthTokenInterface.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\GCECache' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/GCECache.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\GetQuotaProjectInterface' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/GetQuotaProjectInterface.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\HttpHandler\\Guzzle5HttpHandler' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/HttpHandler/Guzzle5HttpHandler.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\HttpHandler\\Guzzle6HttpHandler' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/HttpHandler/Guzzle6HttpHandler.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\HttpHandler\\Guzzle7HttpHandler' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/HttpHandler/Guzzle7HttpHandler.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\HttpHandler\\HttpClientCache' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/HttpHandler/HttpClientCache.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\HttpHandler\\HttpHandlerFactory' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/HttpHandler/HttpHandlerFactory.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Iam' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Iam.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\IamSignerTrait' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/IamSignerTrait.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Middleware\\AuthTokenMiddleware' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Middleware/AuthTokenMiddleware.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Middleware\\ProxyAuthTokenMiddleware' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Middleware/ProxyAuthTokenMiddleware.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Middleware\\ScopedAccessTokenMiddleware' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Middleware/ScopedAccessTokenMiddleware.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\Middleware\\SimpleMiddleware' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/Middleware/SimpleMiddleware.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\OAuth2' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/OAuth2.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\ProjectIdProviderInterface' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/ProjectIdProviderInterface.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\ServiceAccountSignerTrait' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/ServiceAccountSignerTrait.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\SignBlobInterface' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/SignBlobInterface.php',
        'WPMailSMTP\\Vendor\\Google\\Auth\\UpdateMetadataInterface' => __DIR__ . '/../..' . '/vendor_prefixed/google/auth/src/UpdateMetadataInterface.php',
        'WPMailSMTP\\Vendor\\Google\\Client' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Client.php',
        'WPMailSMTP\\Vendor\\Google\\Collection' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Collection.php',
        'WPMailSMTP\\Vendor\\Google\\Exception' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Exception.php',
        'WPMailSMTP\\Vendor\\Google\\Http\\Batch' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Http/Batch.php',
        'WPMailSMTP\\Vendor\\Google\\Http\\MediaFileUpload' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Http/MediaFileUpload.php',
        'WPMailSMTP\\Vendor\\Google\\Http\\REST' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Http/REST.php',
        'WPMailSMTP\\Vendor\\Google\\Model' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Model.php',
        'WPMailSMTP\\Vendor\\Google\\Service' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Service.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Exception' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Service/Exception.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\AutoForwarding' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/AutoForwarding.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\BatchDeleteMessagesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/BatchDeleteMessagesRequest.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\BatchModifyMessagesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/BatchModifyMessagesRequest.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\CseIdentity' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/CseIdentity.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\CseKeyPair' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/CseKeyPair.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\CsePrivateKeyMetadata' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/CsePrivateKeyMetadata.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Delegate' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Delegate.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\DisableCseKeyPairRequest' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/DisableCseKeyPairRequest.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Draft' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Draft.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\EnableCseKeyPairRequest' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/EnableCseKeyPairRequest.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Filter' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Filter.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\FilterAction' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/FilterAction.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\FilterCriteria' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/FilterCriteria.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ForwardingAddress' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ForwardingAddress.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\History' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/History.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\HistoryLabelAdded' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/HistoryLabelAdded.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\HistoryLabelRemoved' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/HistoryLabelRemoved.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\HistoryMessageAdded' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/HistoryMessageAdded.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\HistoryMessageDeleted' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/HistoryMessageDeleted.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ImapSettings' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ImapSettings.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\KaclsKeyMetadata' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/KaclsKeyMetadata.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Label' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Label.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\LabelColor' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/LabelColor.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\LanguageSettings' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/LanguageSettings.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ListCseIdentitiesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ListCseIdentitiesResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ListCseKeyPairsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ListCseKeyPairsResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ListDelegatesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ListDelegatesResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ListDraftsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ListDraftsResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ListFiltersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ListFiltersResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ListForwardingAddressesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ListForwardingAddressesResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ListHistoryResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ListHistoryResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ListLabelsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ListLabelsResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ListMessagesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ListMessagesResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ListSendAsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ListSendAsResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ListSmimeInfoResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ListSmimeInfoResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ListThreadsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ListThreadsResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Message' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Message.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\MessagePart' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/MessagePart.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\MessagePartBody' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/MessagePartBody.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\MessagePartHeader' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/MessagePartHeader.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ModifyMessageRequest' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ModifyMessageRequest.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ModifyThreadRequest' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ModifyThreadRequest.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\ObliterateCseKeyPairRequest' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/ObliterateCseKeyPairRequest.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\PopSettings' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/PopSettings.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Profile' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Profile.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\Users' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/Users.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersDrafts' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersDrafts.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersHistory' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersHistory.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersLabels' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersLabels.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersMessages' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersMessages.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersMessagesAttachments' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersMessagesAttachments.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersSettings' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersSettings.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersSettingsCse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersSettingsCse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersSettingsCseIdentities' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersSettingsCseIdentities.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersSettingsCseKeypairs' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersSettingsCseKeypairs.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersSettingsDelegates' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersSettingsDelegates.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersSettingsFilters' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersSettingsFilters.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersSettingsForwardingAddresses' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersSettingsForwardingAddresses.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersSettingsSendAs' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersSettingsSendAs.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersSettingsSendAsSmimeInfo' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersSettingsSendAsSmimeInfo.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Resource\\UsersThreads' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Resource/UsersThreads.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\SendAs' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/SendAs.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\SmimeInfo' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/SmimeInfo.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\SmtpMsa' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/SmtpMsa.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\Thread' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/Thread.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\VacationSettings' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/VacationSettings.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\WatchRequest' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/WatchRequest.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Gmail\\WatchResponse' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient-services/src/Gmail/WatchResponse.php',
        'WPMailSMTP\\Vendor\\Google\\Service\\Resource' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Service/Resource.php',
        'WPMailSMTP\\Vendor\\Google\\Task\\Composer' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Task/Composer.php',
        'WPMailSMTP\\Vendor\\Google\\Task\\Exception' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Task/Exception.php',
        'WPMailSMTP\\Vendor\\Google\\Task\\Retryable' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Task/Retryable.php',
        'WPMailSMTP\\Vendor\\Google\\Task\\Runner' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Task/Runner.php',
        'WPMailSMTP\\Vendor\\Google\\Utils\\UriTemplate' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/Utils/UriTemplate.php',
        'WPMailSMTP\\Vendor\\Google_AccessToken_Revoke' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_AccessToken_Verify' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_AuthHandler_AuthHandlerFactory' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_AuthHandler_Guzzle5AuthHandler' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_AuthHandler_Guzzle6AuthHandler' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_AuthHandler_Guzzle7AuthHandler' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Client' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Collection' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Exception' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Http_Batch' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Http_MediaFileUpload' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Http_REST' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Model' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Service' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Service_Exception' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Service_Resource' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Task_Composer' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Task_Exception' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Task_Retryable' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Task_Runner' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\Google_Utils_UriTemplate' => __DIR__ . '/../..' . '/vendor_prefixed/google/apiclient/src/aliases.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\BodySummarizer' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/BodySummarizer.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\BodySummarizerInterface' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/BodySummarizerInterface.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Client' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Client.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\ClientInterface' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/ClientInterface.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\ClientTrait' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/ClientTrait.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Cookie\\CookieJar' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Cookie/CookieJar.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Cookie\\CookieJarInterface' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Cookie/CookieJarInterface.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Cookie\\FileCookieJar' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Cookie/FileCookieJar.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Cookie\\SessionCookieJar' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Cookie/SessionCookieJar.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Cookie\\SetCookie' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Cookie/SetCookie.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Exception\\BadResponseException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Exception/BadResponseException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Exception\\ClientException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Exception/ClientException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Exception\\ConnectException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Exception/ConnectException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Exception\\GuzzleException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Exception/GuzzleException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Exception\\InvalidArgumentException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Exception/InvalidArgumentException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Exception\\RequestException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Exception/RequestException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Exception\\ServerException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Exception/ServerException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Exception\\TooManyRedirectsException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Exception/TooManyRedirectsException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Exception\\TransferException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Exception/TransferException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\HandlerStack' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/HandlerStack.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Handler\\CurlFactory' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Handler/CurlFactory.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Handler\\CurlFactoryInterface' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Handler/CurlFactoryInterface.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Handler\\CurlHandler' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Handler/CurlHandler.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Handler\\CurlMultiHandler' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Handler/CurlMultiHandler.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Handler\\EasyHandle' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Handler/EasyHandle.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Handler\\HeaderProcessor' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Handler/HeaderProcessor.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Handler\\MockHandler' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Handler/MockHandler.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Handler\\Proxy' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Handler/Proxy.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Handler\\StreamHandler' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Handler/StreamHandler.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\MessageFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/MessageFormatter.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\MessageFormatterInterface' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/MessageFormatterInterface.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Middleware' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Middleware.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Pool' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Pool.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\PrepareBodyMiddleware' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/PrepareBodyMiddleware.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\AggregateException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/AggregateException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\CancellationException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/CancellationException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\Coroutine' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/Coroutine.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\Create' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/Create.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\Each' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/Each.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\EachPromise' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/EachPromise.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\FulfilledPromise' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/FulfilledPromise.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\Is' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/Is.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\Promise' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/Promise.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\PromiseInterface' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/PromiseInterface.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\PromisorInterface' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/PromisorInterface.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\RejectedPromise' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/RejectedPromise.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\RejectionException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/RejectionException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\TaskQueue' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/TaskQueue.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\TaskQueueInterface' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/TaskQueueInterface.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Promise\\Utils' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/promises/src/Utils.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\AppendStream' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/AppendStream.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\BufferStream' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/BufferStream.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\CachingStream' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/CachingStream.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\DroppingStream' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/DroppingStream.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\Exception\\MalformedUriException' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/Exception/MalformedUriException.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\FnStream' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/FnStream.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\Header' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/Header.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\HttpFactory' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/HttpFactory.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\InflateStream' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/InflateStream.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\LazyOpenStream' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/LazyOpenStream.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\LimitStream' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/LimitStream.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\Message' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/Message.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\MessageTrait' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/MessageTrait.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\MimeType' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/MimeType.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\MultipartStream' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/MultipartStream.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\NoSeekStream' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/NoSeekStream.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\PumpStream' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/PumpStream.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\Query' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/Query.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\Request' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/Request.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\Response' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/Response.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\Rfc7230' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/Rfc7230.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\ServerRequest' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/ServerRequest.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\Stream' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/Stream.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\StreamDecoratorTrait' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/StreamDecoratorTrait.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\StreamWrapper' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/StreamWrapper.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\UploadedFile' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/UploadedFile.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\Uri' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/Uri.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\UriComparator' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/UriComparator.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\UriNormalizer' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/UriNormalizer.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\UriResolver' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/UriResolver.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Psr7\\Utils' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/psr7/src/Utils.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\RedirectMiddleware' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/RedirectMiddleware.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\RequestOptions' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/RequestOptions.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\RetryMiddleware' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/RetryMiddleware.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\TransferStats' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/TransferStats.php',
        'WPMailSMTP\\Vendor\\GuzzleHttp\\Utils' => __DIR__ . '/../..' . '/vendor_prefixed/guzzlehttp/guzzle/src/Utils.php',
        'WPMailSMTP\\Vendor\\Monolog\\ErrorHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/ErrorHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\ChromePHPFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/ChromePHPFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\ElasticaFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/ElasticaFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\FlowdockFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/FlowdockFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\FluentdFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/FluentdFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\FormatterInterface' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/FormatterInterface.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\GelfMessageFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/GelfMessageFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\HtmlFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/HtmlFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\JsonFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/JsonFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\LineFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/LineFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\LogglyFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/LogglyFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\LogstashFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/LogstashFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\MongoDBFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/MongoDBFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\NormalizerFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/NormalizerFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\ScalarFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/ScalarFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Formatter\\WildfireFormatter' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/WildfireFormatter.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\AbstractHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/AbstractHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\AbstractProcessingHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/AbstractProcessingHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\AbstractSyslogHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/AbstractSyslogHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\AmqpHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/AmqpHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\BrowserConsoleHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/BrowserConsoleHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\BufferHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/BufferHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\ChromePHPHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/ChromePHPHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\CouchDBHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/CouchDBHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\CubeHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/CubeHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\Curl\\Util' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/Curl/Util.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\DeduplicationHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/DeduplicationHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\DoctrineCouchDBHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/DoctrineCouchDBHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\DynamoDbHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/DynamoDbHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\ElasticSearchHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/ElasticSearchHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\ErrorLogHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/ErrorLogHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\FilterHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FilterHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\FingersCrossedHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FingersCrossedHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\FingersCrossed\\ActivationStrategyInterface' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FingersCrossed/ActivationStrategyInterface.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\FingersCrossed\\ChannelLevelActivationStrategy' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FingersCrossed/ChannelLevelActivationStrategy.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\FingersCrossed\\ErrorLevelActivationStrategy' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FingersCrossed/ErrorLevelActivationStrategy.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\FirePHPHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FirePHPHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\FleepHookHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FleepHookHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\FlowdockHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FlowdockHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\FormattableHandlerInterface' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FormattableHandlerInterface.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\FormattableHandlerTrait' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FormattableHandlerTrait.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\GelfHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/GelfHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\GroupHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/GroupHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\HandlerInterface' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/HandlerInterface.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\HandlerWrapper' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/HandlerWrapper.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\HipChatHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/HipChatHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\IFTTTHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/IFTTTHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\InsightOpsHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/InsightOpsHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\LogEntriesHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/LogEntriesHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\LogglyHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/LogglyHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\MailHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/MailHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\MandrillHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/MandrillHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\MissingExtensionException' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/MissingExtensionException.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\MongoDBHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/MongoDBHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\NativeMailerHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/NativeMailerHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\NewRelicHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/NewRelicHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\NullHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/NullHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\PHPConsoleHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/PHPConsoleHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\ProcessableHandlerInterface' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/ProcessableHandlerInterface.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\ProcessableHandlerTrait' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/ProcessableHandlerTrait.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\PsrHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/PsrHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\PushoverHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/PushoverHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\RavenHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/RavenHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\RedisHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/RedisHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\RollbarHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/RollbarHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\RotatingFileHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/RotatingFileHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\SamplingHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SamplingHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\SlackHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SlackHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\SlackWebhookHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SlackWebhookHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\Slack\\SlackRecord' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/Slack/SlackRecord.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\SlackbotHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SlackbotHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\SocketHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SocketHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\StreamHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/StreamHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\SwiftMailerHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SwiftMailerHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\SyslogHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SyslogHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\SyslogUdpHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SyslogUdpHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\SyslogUdp\\UdpSocket' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SyslogUdp/UdpSocket.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\TestHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/TestHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\WhatFailureGroupHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/WhatFailureGroupHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Handler\\ZendMonitorHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/ZendMonitorHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Logger' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Logger.php',
        'WPMailSMTP\\Vendor\\Monolog\\Processor\\GitProcessor' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/GitProcessor.php',
        'WPMailSMTP\\Vendor\\Monolog\\Processor\\IntrospectionProcessor' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/IntrospectionProcessor.php',
        'WPMailSMTP\\Vendor\\Monolog\\Processor\\MemoryPeakUsageProcessor' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/MemoryPeakUsageProcessor.php',
        'WPMailSMTP\\Vendor\\Monolog\\Processor\\MemoryProcessor' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/MemoryProcessor.php',
        'WPMailSMTP\\Vendor\\Monolog\\Processor\\MemoryUsageProcessor' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/MemoryUsageProcessor.php',
        'WPMailSMTP\\Vendor\\Monolog\\Processor\\MercurialProcessor' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/MercurialProcessor.php',
        'WPMailSMTP\\Vendor\\Monolog\\Processor\\ProcessIdProcessor' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/ProcessIdProcessor.php',
        'WPMailSMTP\\Vendor\\Monolog\\Processor\\ProcessorInterface' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/ProcessorInterface.php',
        'WPMailSMTP\\Vendor\\Monolog\\Processor\\PsrLogMessageProcessor' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/PsrLogMessageProcessor.php',
        'WPMailSMTP\\Vendor\\Monolog\\Processor\\TagProcessor' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/TagProcessor.php',
        'WPMailSMTP\\Vendor\\Monolog\\Processor\\UidProcessor' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/UidProcessor.php',
        'WPMailSMTP\\Vendor\\Monolog\\Processor\\WebProcessor' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/WebProcessor.php',
        'WPMailSMTP\\Vendor\\Monolog\\Registry' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Registry.php',
        'WPMailSMTP\\Vendor\\Monolog\\ResettableInterface' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/ResettableInterface.php',
        'WPMailSMTP\\Vendor\\Monolog\\SignalHandler' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/SignalHandler.php',
        'WPMailSMTP\\Vendor\\Monolog\\Utils' => __DIR__ . '/../..' . '/vendor_prefixed/monolog/monolog/src/Monolog/Utils.php',
        'WPMailSMTP\\Vendor\\ParagonIE\\ConstantTime\\Base32' => __DIR__ . '/../..' . '/vendor_prefixed/paragonie/constant_time_encoding/src/Base32.php',
        'WPMailSMTP\\Vendor\\ParagonIE\\ConstantTime\\Base32Hex' => __DIR__ . '/../..' . '/vendor_prefixed/paragonie/constant_time_encoding/src/Base32Hex.php',
        'WPMailSMTP\\Vendor\\ParagonIE\\ConstantTime\\Base64' => __DIR__ . '/../..' . '/vendor_prefixed/paragonie/constant_time_encoding/src/Base64.php',
        'WPMailSMTP\\Vendor\\ParagonIE\\ConstantTime\\Base64DotSlash' => __DIR__ . '/../..' . '/vendor_prefixed/paragonie/constant_time_encoding/src/Base64DotSlash.php',
        'WPMailSMTP\\Vendor\\ParagonIE\\ConstantTime\\Base64DotSlashOrdered' => __DIR__ . '/../..' . '/vendor_prefixed/paragonie/constant_time_encoding/src/Base64DotSlashOrdered.php',
        'WPMailSMTP\\Vendor\\ParagonIE\\ConstantTime\\Base64UrlSafe' => __DIR__ . '/../..' . '/vendor_prefixed/paragonie/constant_time_encoding/src/Base64UrlSafe.php',
        'WPMailSMTP\\Vendor\\ParagonIE\\ConstantTime\\Binary' => __DIR__ . '/../..' . '/vendor_prefixed/paragonie/constant_time_encoding/src/Binary.php',
        'WPMailSMTP\\Vendor\\ParagonIE\\ConstantTime\\EncoderInterface' => __DIR__ . '/../..' . '/vendor_prefixed/paragonie/constant_time_encoding/src/EncoderInterface.php',
        'WPMailSMTP\\Vendor\\ParagonIE\\ConstantTime\\Encoding' => __DIR__ . '/../..' . '/vendor_prefixed/paragonie/constant_time_encoding/src/Encoding.php',
        'WPMailSMTP\\Vendor\\ParagonIE\\ConstantTime\\Hex' => __DIR__ . '/../..' . '/vendor_prefixed/paragonie/constant_time_encoding/src/Hex.php',
        'WPMailSMTP\\Vendor\\ParagonIE\\ConstantTime\\RFC4648' => __DIR__ . '/../..' . '/vendor_prefixed/paragonie/constant_time_encoding/src/RFC4648.php',
        'WPMailSMTP\\Vendor\\Psr\\Cache\\CacheException' => __DIR__ . '/../..' . '/vendor_prefixed/psr/cache/src/CacheException.php',
        'WPMailSMTP\\Vendor\\Psr\\Cache\\CacheItemInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/cache/src/CacheItemInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Cache\\CacheItemPoolInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/cache/src/CacheItemPoolInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Cache\\InvalidArgumentException' => __DIR__ . '/../..' . '/vendor_prefixed/psr/cache/src/InvalidArgumentException.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Client\\ClientExceptionInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-client/src/ClientExceptionInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Client\\ClientInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-client/src/ClientInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Client\\NetworkExceptionInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-client/src/NetworkExceptionInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Client\\RequestExceptionInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-client/src/RequestExceptionInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\MessageInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-message/src/MessageInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\RequestFactoryInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-factory/src/RequestFactoryInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\RequestInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-message/src/RequestInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\ResponseFactoryInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-factory/src/ResponseFactoryInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\ResponseInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-message/src/ResponseInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\ServerRequestFactoryInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-factory/src/ServerRequestFactoryInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\ServerRequestInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-message/src/ServerRequestInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\StreamFactoryInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-factory/src/StreamFactoryInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\StreamInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-message/src/StreamInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\UploadedFileFactoryInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-factory/src/UploadedFileFactoryInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\UploadedFileInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-message/src/UploadedFileInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\UriFactoryInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-factory/src/UriFactoryInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Http\\Message\\UriInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/http-message/src/UriInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Log\\AbstractLogger' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/AbstractLogger.php',
        'WPMailSMTP\\Vendor\\Psr\\Log\\InvalidArgumentException' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/InvalidArgumentException.php',
        'WPMailSMTP\\Vendor\\Psr\\Log\\LogLevel' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/LogLevel.php',
        'WPMailSMTP\\Vendor\\Psr\\Log\\LoggerAwareInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/LoggerAwareInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Log\\LoggerAwareTrait' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/LoggerAwareTrait.php',
        'WPMailSMTP\\Vendor\\Psr\\Log\\LoggerInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/LoggerInterface.php',
        'WPMailSMTP\\Vendor\\Psr\\Log\\LoggerTrait' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/LoggerTrait.php',
        'WPMailSMTP\\Vendor\\Psr\\Log\\NullLogger' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/NullLogger.php',
        'WPMailSMTP\\Vendor\\Psr\\Log\\Test\\DummyTest' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/Test/DummyTest.php',
        'WPMailSMTP\\Vendor\\Psr\\Log\\Test\\LoggerInterfaceTest' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/Test/LoggerInterfaceTest.php',
        'WPMailSMTP\\Vendor\\Psr\\Log\\Test\\TestLogger' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/Test/TestLogger.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\ApiException' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/ApiException.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\AccountApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/AccountApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\AttributesApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/AttributesApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\CRMApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/CRMApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\CompaniesApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/CompaniesApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\ContactsApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/ContactsApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\ConversationsApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/ConversationsApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\DealsApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/DealsApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\EcommerceApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/EcommerceApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\EmailCampaignsApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/EmailCampaignsApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\FilesApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/FilesApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\FoldersApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/FoldersApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\InboundParsingApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/InboundParsingApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\ListsApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/ListsApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\MasterAccountApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/MasterAccountApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\NotesApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/NotesApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\ProcessApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/ProcessApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\ResellerApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/ResellerApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\SMSCampaignsApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/SMSCampaignsApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\SendersApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/SendersApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\TasksApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/TasksApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\TransactionalEmailsApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/TransactionalEmailsApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\TransactionalSMSApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/TransactionalSMSApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\TransactionalWhatsAppApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/TransactionalWhatsAppApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\WebhooksApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/WebhooksApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Api\\WhatsappCampaignsApi' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Api/WhatsappCampaignsApi.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Configuration' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Configuration.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\HeaderSelector' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/HeaderSelector.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\AbTestCampaignResult' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/AbTestCampaignResult.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\AbTestCampaignResultClickedLinks' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/AbTestCampaignResultClickedLinks.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\AbTestCampaignResultStatistics' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/AbTestCampaignResultStatistics.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\AbTestVersionClicksInner' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/AbTestVersionClicksInner.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\AbTestVersionStats' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/AbTestVersionStats.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\AddChildDomain' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/AddChildDomain.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\AddContactToList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/AddContactToList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\AddCredits' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/AddCredits.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\BlockDomain' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/BlockDomain.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body1' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body1.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body10' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body10.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body11' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body11.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body12' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body12.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body2' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body2.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body3' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body3.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body4' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body4.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body5' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body5.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body6' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body6.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body7' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body7.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body8' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body8.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Body9' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Body9.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\BodyVariablesItems' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/BodyVariablesItems.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CompaniesList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CompaniesList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Company' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Company.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CompanyAttributesInner' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CompanyAttributesInner.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\ComponentItems' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/ComponentItems.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Contact' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Contact.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\ConversationsMessage' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/ConversationsMessage.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\ConversationsMessageFile' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/ConversationsMessageFile.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\ConversationsMessageFileImageInfo' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/ConversationsMessageFileImageInfo.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateApiKeyRequest' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateApiKeyRequest.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateApiKeyResponse' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateApiKeyResponse.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateAttribute' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateAttribute.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateAttributeEnumeration' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateAttributeEnumeration.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateCategoryModel' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateCategoryModel.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateChild' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateChild.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateContact' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateContact.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateDoiContact' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateDoiContact.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateEmailCampaign' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateEmailCampaign.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateEmailCampaignRecipients' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateEmailCampaignRecipients.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateEmailCampaignSender' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateEmailCampaignSender.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateModel' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateModel.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateProductModel' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateProductModel.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateReseller' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateReseller.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateSender' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateSender.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateSenderIps' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateSenderIps.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateSenderModel' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateSenderModel.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateSmsCampaign' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateSmsCampaign.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateSmsCampaignRecipients' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateSmsCampaignRecipients.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateSmtpEmail' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateSmtpEmail.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateSmtpTemplate' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateSmtpTemplate.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateSmtpTemplateSender' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateSmtpTemplateSender.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateSubAccount' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateSubAccount.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateSubAccountResponse' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateSubAccountResponse.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateUpdateBatchCategory' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateUpdateBatchCategory.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateUpdateBatchCategoryModel' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateUpdateBatchCategoryModel.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateUpdateBatchProducts' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateUpdateBatchProducts.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateUpdateBatchProductsModel' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateUpdateBatchProductsModel.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateUpdateCategories' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateUpdateCategories.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateUpdateCategory' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateUpdateCategory.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateUpdateContactModel' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateUpdateContactModel.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateUpdateFolder' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateUpdateFolder.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateUpdateProduct' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateUpdateProduct.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateUpdateProducts' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateUpdateProducts.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreateWebhook' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreateWebhook.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreatedBatchId' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreatedBatchId.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\CreatedProcessId' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/CreatedProcessId.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Deal' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Deal.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\DealAttributesInner' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/DealAttributesInner.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\DealsList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/DealsList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\DeleteHardbounces' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/DeleteHardbounces.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\EmailExportRecipients' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/EmailExportRecipients.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\ErrorModel' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/ErrorModel.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\FileData' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/FileData.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\FileDownloadableLink' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/FileDownloadableLink.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetAccount' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetAccount.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetAccountMarketingAutomation' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetAccountMarketingAutomation.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetAccountPlan' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetAccountPlan.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetAccountRelay' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetAccountRelay.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetAccountRelayData' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetAccountRelayData.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetAggregatedReport' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetAggregatedReport.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetAttributes.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetAttributesAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetAttributesAttributes.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetAttributesEnumeration' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetAttributesEnumeration.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetBlockedDomains' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetBlockedDomains.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetCampaignOverview' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetCampaignOverview.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetCampaignRecipients' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetCampaignRecipients.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetCampaignStats' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetCampaignStats.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetCategories' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetCategories.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetCategoryDetails' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetCategoryDetails.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetChildAccountCreationStatus' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetChildAccountCreationStatus.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetChildDomain' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetChildDomain.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetChildInfo' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetChildInfo.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetChildInfoApiKeys' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetChildInfoApiKeys.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetChildInfoApiKeysV2' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetChildInfoApiKeysV2.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetChildInfoApiKeysV3' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetChildInfoApiKeysV3.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetChildInfoCredits' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetChildInfoCredits.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetChildInfoStatistics' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetChildInfoStatistics.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetChildrenList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetChildrenList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetClient' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetClient.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetContactCampaignStats' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetContactCampaignStats.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetContactCampaignStatsClicked' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetContactCampaignStatsClicked.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetContactCampaignStatsOpened' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetContactCampaignStatsOpened.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetContactCampaignStatsTransacAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetContactCampaignStatsTransacAttributes.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetContactCampaignStatsUnsubscriptions' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetContactCampaignStatsUnsubscriptions.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetContactDetails' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetContactDetails.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetContacts' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetContacts.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetDeviceBrowserStats' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetDeviceBrowserStats.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetEmailCampaign' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetEmailCampaign.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetEmailCampaigns' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetEmailCampaigns.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetEmailEventReport' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetEmailEventReport.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetEmailEventReportEvents' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetEmailEventReportEvents.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedCampaignOverview' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedCampaignOverview.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedCampaignOverviewSender' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedCampaignOverviewSender.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedCampaignStats' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedCampaignStats.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedCampaignStatsGlobalStats' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedCampaignStatsGlobalStats.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedClient' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedClient.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedClientAddress' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedClientAddress.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedContactDetails' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedContactDetails.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedContactDetailsStatistics' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedContactDetailsStatistics.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedContactDetailsStatisticsClicked' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedContactDetailsStatisticsClicked.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedContactDetailsStatisticsDelivered' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedContactDetailsStatisticsDelivered.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedContactDetailsStatisticsLinks' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedContactDetailsStatisticsLinks.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedContactDetailsStatisticsMessagesSent' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedContactDetailsStatisticsMessagesSent.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedContactDetailsStatisticsOpened' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedContactDetailsStatisticsOpened.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedContactDetailsStatisticsUnsubscriptions' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedContactDetailsStatisticsUnsubscriptions.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedContactDetailsStatisticsUnsubscriptionsAdminUnsubscription' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedContactDetailsStatisticsUnsubscriptionsAdminUnsubscription.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedContactDetailsStatisticsUnsubscriptionsUserUnsubscription' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedContactDetailsStatisticsUnsubscriptionsUserUnsubscription.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetExtendedListCampaignStats' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetExtendedListCampaignStats.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetFolder' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetFolder.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetFolderLists' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetFolderLists.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetFolders' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetFolders.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetInboundEmailEvents' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetInboundEmailEvents.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetInboundEmailEventsByUuid' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetInboundEmailEventsByUuid.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetInboundEmailEventsByUuidAttachments' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetInboundEmailEventsByUuidAttachments.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetInboundEmailEventsByUuidLogs' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetInboundEmailEventsByUuidLogs.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetInboundEmailEventsEvents' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetInboundEmailEventsEvents.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetIp' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetIp.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetIpFromSender' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetIpFromSender.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetIps' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetIps.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetIpsFromSender' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetIpsFromSender.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetLists' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetLists.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetProcess' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetProcess.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetProcesses' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetProcesses.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetProductDetails' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetProductDetails.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetProducts' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetProducts.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetReports' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetReports.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetReportsReports' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetReportsReports.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetScheduledEmailByBatchId' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetScheduledEmailByBatchId.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetScheduledEmailByBatchIdBatches' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetScheduledEmailByBatchIdBatches.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetScheduledEmailByMessageId' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetScheduledEmailByMessageId.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSendersList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSendersList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSendersListIps' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSendersListIps.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSendersListSenders' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSendersListSenders.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSharedTemplateUrl' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSharedTemplateUrl.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSmsCampaign' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSmsCampaign.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSmsCampaignOverview' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSmsCampaignOverview.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSmsCampaignRecipients' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSmsCampaignRecipients.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSmsCampaignStats' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSmsCampaignStats.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSmsCampaigns' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSmsCampaigns.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSmsEventReport' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSmsEventReport.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSmsEventReportEvents' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSmsEventReportEvents.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSmtpTemplateOverview' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSmtpTemplateOverview.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSmtpTemplateOverviewSender' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSmtpTemplateOverviewSender.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSmtpTemplates' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSmtpTemplates.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetSsoToken' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetSsoToken.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetStatsByDevice' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetStatsByDevice.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetTransacAggregatedSmsReport' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetTransacAggregatedSmsReport.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetTransacBlockedContacts' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetTransacBlockedContacts.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetTransacBlockedContactsContacts' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetTransacBlockedContactsContacts.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetTransacBlockedContactsReason' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetTransacBlockedContactsReason.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetTransacEmailContent' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetTransacEmailContent.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetTransacEmailContentEvents' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetTransacEmailContentEvents.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetTransacEmailsList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetTransacEmailsList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetTransacEmailsListTransactionalEmails' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetTransacEmailsListTransactionalEmails.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetTransacSmsReport' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetTransacSmsReport.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetTransacSmsReportReports' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetTransacSmsReportReports.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetWebhook' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetWebhook.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetWebhooks' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetWebhooks.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetWhatsappCampaignOverview' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetWhatsappCampaignOverview.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetWhatsappEventReport' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetWhatsappEventReport.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\GetWhatsappEventReportEvents' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/GetWhatsappEventReportEvents.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\InlineResponse200' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/InlineResponse200.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\InlineResponse201' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/InlineResponse201.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\InlineResponse2011' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/InlineResponse2011.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\InlineResponse2012' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/InlineResponse2012.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\ManageIp' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/ManageIp.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\MasterDetailsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/MasterDetailsResponse.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\MasterDetailsResponseBillingInfo' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/MasterDetailsResponseBillingInfo.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\MasterDetailsResponseBillingInfoAddress' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/MasterDetailsResponseBillingInfoAddress.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\MasterDetailsResponseBillingInfoName' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/MasterDetailsResponseBillingInfoName.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\MasterDetailsResponsePlanInfo' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/MasterDetailsResponsePlanInfo.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\MasterDetailsResponsePlanInfoFeatures' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/MasterDetailsResponsePlanInfoFeatures.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\ModelInterface' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/ModelInterface.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Note' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Note.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\NoteData' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/NoteData.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\NoteId' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/NoteId.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Order' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Order.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\OrderBatch' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/OrderBatch.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\OrderBilling' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/OrderBilling.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\OrderProducts' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/OrderProducts.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Pipeline' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Pipeline.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\PipelineStage' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/PipelineStage.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\PostContactInfo' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/PostContactInfo.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\PostContactInfoContacts' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/PostContactInfoContacts.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\PostSendFailed' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/PostSendFailed.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\PostSendSmsTestFailed' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/PostSendSmsTestFailed.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\RemainingCreditModel' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/RemainingCreditModel.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\RemainingCreditModelChild' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/RemainingCreditModelChild.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\RemainingCreditModelReseller' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/RemainingCreditModelReseller.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\RemoveContactFromList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/RemoveContactFromList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\RemoveCredits' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/RemoveCredits.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\RequestContactExport' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/RequestContactExport.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\RequestContactExportCustomContactFilter' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/RequestContactExportCustomContactFilter.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\RequestContactImport' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/RequestContactImport.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\RequestContactImportNewList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/RequestContactImportNewList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\RequestSmsRecipientExport' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/RequestSmsRecipientExport.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\ScheduleSmtpEmail' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/ScheduleSmtpEmail.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendReport' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendReport.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendReportEmail' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendReportEmail.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendSms' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendSms.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendSmtpEmail' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendSmtpEmail.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendSmtpEmailAttachment' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendSmtpEmailAttachment.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendSmtpEmailBcc' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendSmtpEmailBcc.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendSmtpEmailCc' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendSmtpEmailCc.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendSmtpEmailMessageVersions' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendSmtpEmailMessageVersions.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendSmtpEmailReplyTo' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendSmtpEmailReplyTo.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendSmtpEmailReplyTo1' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendSmtpEmailReplyTo1.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendSmtpEmailSender' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendSmtpEmailSender.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendSmtpEmailTo' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendSmtpEmailTo.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendSmtpEmailTo1' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendSmtpEmailTo1.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendTestEmail' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendTestEmail.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendTestSms' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendTestSms.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendTransacSms' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendTransacSms.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SendWhatsappMessage' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SendWhatsappMessage.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SsoTokenRequest' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SsoTokenRequest.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountDetailsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountDetailsResponse.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountDetailsResponsePlanInfo' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountDetailsResponsePlanInfo.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountDetailsResponsePlanInfoCredits' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountDetailsResponsePlanInfoCredits.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountDetailsResponsePlanInfoCreditsEmails' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountDetailsResponsePlanInfoCreditsEmails.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountDetailsResponsePlanInfoFeatures' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountDetailsResponsePlanInfoFeatures.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountDetailsResponsePlanInfoFeaturesInbox' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountDetailsResponsePlanInfoFeaturesInbox.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountDetailsResponsePlanInfoFeaturesLandingPage' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountDetailsResponsePlanInfoFeaturesLandingPage.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountDetailsResponsePlanInfoFeaturesUsers' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountDetailsResponsePlanInfoFeaturesUsers.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountUpdatePlanRequest' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountUpdatePlanRequest.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountUpdatePlanRequestCredits' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountUpdatePlanRequestCredits.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountUpdatePlanRequestFeatures' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountUpdatePlanRequestFeatures.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountsResponse.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\SubAccountsResponseSubAccounts' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/SubAccountsResponseSubAccounts.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\Task' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/Task.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\TaskList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/TaskList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\TaskReminder' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/TaskReminder.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\TaskTypes' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/TaskTypes.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateAttribute' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateAttribute.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateAttributeEnumeration' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateAttributeEnumeration.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateBatchContacts' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateBatchContacts.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateBatchContactsContacts' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateBatchContactsContacts.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateBatchContactsModel' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateBatchContactsModel.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateCampaignStatus' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateCampaignStatus.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateChild' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateChild.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateChildAccountStatus' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateChildAccountStatus.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateChildDomain' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateChildDomain.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateContact' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateContact.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateEmailCampaign' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateEmailCampaign.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateEmailCampaignRecipients' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateEmailCampaignRecipients.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateEmailCampaignSender' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateEmailCampaignSender.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateList' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateList.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateSender' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateSender.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateSmsCampaign' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateSmsCampaign.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateSmtpTemplate' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateSmtpTemplate.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateSmtpTemplateSender' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateSmtpTemplateSender.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UpdateWebhook' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UpdateWebhook.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UploadImageModel' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UploadImageModel.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\UploadImageToGallery' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/UploadImageToGallery.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\VariablesItems' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/VariablesItems.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\WhatsappCampStats' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/WhatsappCampStats.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\Model\\WhatsappCampTemplate' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/Model/WhatsappCampTemplate.php',
        'WPMailSMTP\\Vendor\\SendinBlue\\Client\\ObjectSerializer' => __DIR__ . '/../..' . '/vendor_prefixed/sendinblue/api-v3-sdk/lib/ObjectSerializer.php',
        'WPMailSMTP\\Vendor\\Symfony\\Polyfill\\Intl\\Idn\\Idn' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/polyfill-intl-idn/Idn.php',
        'WPMailSMTP\\Vendor\\Symfony\\Polyfill\\Mbstring\\Mbstring' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/polyfill-mbstring/Mbstring.php',
        'WPMailSMTP\\Vendor\\Symfony\\Polyfill\\Php72\\Php72' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/polyfill-php72/Php72.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Common\\Functions\\Strings' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Common/Functions/Strings.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\AES' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/AES.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Blowfish' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Blowfish.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\ChaCha20' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/ChaCha20.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\AsymmetricKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/AsymmetricKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\BlockCipher' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/BlockCipher.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\Formats\\Keys\\JWK' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/JWK.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\Formats\\Keys\\OpenSSH' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/OpenSSH.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\Formats\\Keys\\PKCS' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/PKCS.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\Formats\\Keys\\PKCS1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/PKCS1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\Formats\\Keys\\PKCS8' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/PKCS8.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\Formats\\Keys\\PuTTY' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/PuTTY.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\Formats\\Signature\\Raw' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Signature/Raw.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\PrivateKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/PrivateKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\PublicKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/PublicKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\StreamCipher' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/StreamCipher.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\SymmetricKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/SymmetricKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\Traits\\Fingerprint' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/Traits/Fingerprint.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Common\\Traits\\PasswordProtected' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Common/Traits/PasswordProtected.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DES' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DES.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DH' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DH.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DH\\Formats\\Keys\\PKCS1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DH/Formats/Keys/PKCS1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DH\\Formats\\Keys\\PKCS8' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DH/Formats/Keys/PKCS8.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DH\\Parameters' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DH/Parameters.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DH\\PrivateKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DH/PrivateKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DH\\PublicKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DH/PublicKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA\\Formats\\Keys\\OpenSSH' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/OpenSSH.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA\\Formats\\Keys\\PKCS1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/PKCS1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA\\Formats\\Keys\\PKCS8' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/PKCS8.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA\\Formats\\Keys\\PuTTY' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/PuTTY.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA\\Formats\\Keys\\Raw' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/Raw.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA\\Formats\\Keys\\XML' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/XML.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA\\Formats\\Signature\\ASN1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Signature/ASN1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA\\Formats\\Signature\\Raw' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Signature/Raw.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA\\Formats\\Signature\\SSH2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Signature/SSH2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA\\Parameters' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA/Parameters.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA\\PrivateKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA/PrivateKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\DSA\\PublicKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/DSA/PublicKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\BaseCurves\\Base' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/Base.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\BaseCurves\\Binary' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/Binary.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\BaseCurves\\KoblitzPrime' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/KoblitzPrime.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\BaseCurves\\Montgomery' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/Montgomery.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\BaseCurves\\Prime' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/Prime.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\BaseCurves\\TwistedEdwards' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/TwistedEdwards.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\Curve25519' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/Curve25519.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\Curve448' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/Curve448.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\Ed25519' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/Ed25519.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\Ed448' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/Ed448.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP160r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP160r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP160t1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP160t1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP192r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP192r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP192t1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP192t1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP224r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP224r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP224t1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP224t1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP256r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP256r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP256t1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP256t1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP320r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP320r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP320t1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP320t1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP384r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP384r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP384t1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP384t1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP512r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP512r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP512t1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP512t1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\nistb233' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistb233.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\nistb409' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistb409.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\nistk163' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistk163.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\nistk233' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistk233.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\nistk283' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistk283.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\nistk409' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistk409.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\nistp192' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp192.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\nistp224' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp224.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\nistp256' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp256.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\nistp384' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp384.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\nistp521' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp521.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\nistt571' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistt571.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\prime192v1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime192v1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\prime192v2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime192v2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\prime192v3' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime192v3.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\prime239v1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime239v1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\prime239v2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime239v2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\prime239v3' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime239v3.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\prime256v1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime256v1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp112r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp112r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp112r2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp112r2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp128r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp128r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp128r2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp128r2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp160k1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp160k1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp160r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp160r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp160r2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp160r2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp192k1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp192k1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp192r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp192r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp224k1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp224k1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp224r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp224r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp256k1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp256k1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp256r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp256r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp384r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp384r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\secp521r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp521r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect113r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect113r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect113r2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect113r2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect131r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect131r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect131r2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect131r2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect163k1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect163k1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect163r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect163r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect163r2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect163r2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect193r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect193r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect193r2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect193r2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect233k1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect233k1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect233r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect233r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect239k1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect239k1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect283k1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect283k1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect283r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect283r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect409k1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect409k1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect409r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect409r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect571k1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect571k1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Curves\\sect571r1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect571r1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\Common' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/Common.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\JWK' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/JWK.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\MontgomeryPrivate' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/MontgomeryPrivate.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\MontgomeryPublic' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/MontgomeryPublic.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\OpenSSH' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/OpenSSH.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\PKCS1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/PKCS1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\PKCS8' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/PKCS8.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\PuTTY' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/PuTTY.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\XML' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/XML.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\libsodium' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/libsodium.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Signature\\ASN1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Signature/ASN1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Signature\\Raw' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Signature/Raw.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Formats\\Signature\\SSH2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Signature/SSH2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\Parameters' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/Parameters.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\PrivateKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/PrivateKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\EC\\PublicKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/EC/PublicKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Hash' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Hash.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\PublicKeyLoader' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/PublicKeyLoader.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RC2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RC2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RC4' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RC4.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RSA' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RSA.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\JWK' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/JWK.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\MSBLOB' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/MSBLOB.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\OpenSSH' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/OpenSSH.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\PKCS1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/PKCS1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\PKCS8' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/PKCS8.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\PSS' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/PSS.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\PuTTY' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/PuTTY.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\Raw' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/Raw.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\XML' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/XML.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RSA\\PrivateKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RSA/PrivateKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\RSA\\PublicKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/RSA/PublicKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Random' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Random.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Rijndael' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Rijndael.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Salsa20' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Salsa20.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\TripleDES' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/TripleDES.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Crypt\\Twofish' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Crypt/Twofish.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\BadConfigurationException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/BadConfigurationException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\BadDecryptionException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/BadDecryptionException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\BadModeException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/BadModeException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\ConnectionClosedException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/ConnectionClosedException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\FileNotFoundException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/FileNotFoundException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\InconsistentSetupException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/InconsistentSetupException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\InsufficientSetupException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/InsufficientSetupException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\NoKeyLoadedException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/NoKeyLoadedException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\NoSupportedAlgorithmsException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/NoSupportedAlgorithmsException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\UnableToConnectException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/UnableToConnectException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\UnsupportedAlgorithmException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/UnsupportedAlgorithmException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\UnsupportedCurveException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/UnsupportedCurveException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\UnsupportedFormatException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/UnsupportedFormatException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Exception\\UnsupportedOperationException' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Exception/UnsupportedOperationException.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ANSI' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ANSI.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Element' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Element.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\AccessDescription' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AccessDescription.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\AdministrationDomainName' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AdministrationDomainName.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\AlgorithmIdentifier' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AlgorithmIdentifier.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\AnotherName' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AnotherName.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Attribute' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Attribute.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\AttributeType' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AttributeType.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\AttributeTypeAndValue' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AttributeTypeAndValue.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\AttributeValue' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AttributeValue.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Attributes' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Attributes.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\AuthorityInfoAccessSyntax' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AuthorityInfoAccessSyntax.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\AuthorityKeyIdentifier' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AuthorityKeyIdentifier.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\BaseDistance' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BaseDistance.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\BasicConstraints' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BasicConstraints.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\BuiltInDomainDefinedAttribute' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BuiltInDomainDefinedAttribute.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\BuiltInDomainDefinedAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BuiltInDomainDefinedAttributes.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\BuiltInStandardAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BuiltInStandardAttributes.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\CPSuri' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CPSuri.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\CRLDistributionPoints' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CRLDistributionPoints.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\CRLNumber' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CRLNumber.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\CRLReason' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CRLReason.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\CertPolicyId' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertPolicyId.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Certificate' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Certificate.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\CertificateIssuer' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificateIssuer.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\CertificateList' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificateList.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\CertificatePolicies' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificatePolicies.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\CertificateSerialNumber' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificateSerialNumber.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\CertificationRequest' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificationRequest.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\CertificationRequestInfo' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificationRequestInfo.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Characteristic_two' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Characteristic_two.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\CountryName' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CountryName.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Curve' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Curve.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\DHParameter' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DHParameter.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\DSAParams' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DSAParams.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\DSAPrivateKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DSAPrivateKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\DSAPublicKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DSAPublicKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\DigestInfo' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DigestInfo.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\DirectoryString' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DirectoryString.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\DisplayText' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DisplayText.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\DistributionPoint' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DistributionPoint.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\DistributionPointName' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DistributionPointName.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\DssSigValue' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DssSigValue.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\ECParameters' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ECParameters.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\ECPoint' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ECPoint.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\ECPrivateKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ECPrivateKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\EDIPartyName' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/EDIPartyName.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\EcdsaSigValue' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/EcdsaSigValue.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\EncryptedData' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/EncryptedData.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\EncryptedPrivateKeyInfo' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/EncryptedPrivateKeyInfo.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\ExtKeyUsageSyntax' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ExtKeyUsageSyntax.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Extension' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Extension.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\ExtensionAttribute' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ExtensionAttribute.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\ExtensionAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ExtensionAttributes.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Extensions' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Extensions.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\FieldElement' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/FieldElement.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\FieldID' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/FieldID.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\GeneralName' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/GeneralName.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\GeneralNames' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/GeneralNames.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\GeneralSubtree' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/GeneralSubtree.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\GeneralSubtrees' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/GeneralSubtrees.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\HashAlgorithm' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/HashAlgorithm.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\HoldInstructionCode' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/HoldInstructionCode.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\InvalidityDate' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/InvalidityDate.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\IssuerAltName' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/IssuerAltName.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\IssuingDistributionPoint' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/IssuingDistributionPoint.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\KeyIdentifier' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/KeyIdentifier.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\KeyPurposeId' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/KeyPurposeId.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\KeyUsage' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/KeyUsage.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\MaskGenAlgorithm' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/MaskGenAlgorithm.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Name' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Name.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\NameConstraints' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/NameConstraints.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\NetworkAddress' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/NetworkAddress.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\NoticeReference' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/NoticeReference.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\NumericUserIdentifier' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/NumericUserIdentifier.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\ORAddress' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ORAddress.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\OneAsymmetricKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OneAsymmetricKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\OrganizationName' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OrganizationName.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\OrganizationalUnitNames' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OrganizationalUnitNames.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\OtherPrimeInfo' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OtherPrimeInfo.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\OtherPrimeInfos' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OtherPrimeInfos.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PBEParameter' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PBEParameter.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PBES2params' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PBES2params.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PBKDF2params' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PBKDF2params.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PBMAC1params' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PBMAC1params.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PKCS9String' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PKCS9String.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Pentanomial' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Pentanomial.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PersonalName' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PersonalName.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PolicyInformation' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PolicyInformation.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PolicyMappings' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PolicyMappings.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PolicyQualifierId' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PolicyQualifierId.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PolicyQualifierInfo' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PolicyQualifierInfo.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PostalAddress' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PostalAddress.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Prime_p' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Prime_p.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PrivateDomainName' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PrivateDomainName.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PrivateKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PrivateKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PrivateKeyInfo' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PrivateKeyInfo.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PrivateKeyUsagePeriod' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PrivateKeyUsagePeriod.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PublicKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PublicKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PublicKeyAndChallenge' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PublicKeyAndChallenge.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\PublicKeyInfo' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PublicKeyInfo.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\RC2CBCParameter' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RC2CBCParameter.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\RDNSequence' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RDNSequence.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\RSAPrivateKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RSAPrivateKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\RSAPublicKey' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RSAPublicKey.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\RSASSA_PSS_params' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RSASSA_PSS_params.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\ReasonFlags' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ReasonFlags.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\RelativeDistinguishedName' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RelativeDistinguishedName.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\RevokedCertificate' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RevokedCertificate.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\SignedPublicKeyAndChallenge' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SignedPublicKeyAndChallenge.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\SpecifiedECDomain' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SpecifiedECDomain.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\SubjectAltName' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SubjectAltName.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\SubjectDirectoryAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SubjectDirectoryAttributes.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\SubjectInfoAccessSyntax' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SubjectInfoAccessSyntax.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\SubjectPublicKeyInfo' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SubjectPublicKeyInfo.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\TBSCertList' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/TBSCertList.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\TBSCertificate' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/TBSCertificate.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\TerminalIdentifier' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/TerminalIdentifier.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Time' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Time.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Trinomial' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Trinomial.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\UniqueIdentifier' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/UniqueIdentifier.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\UserNotice' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/UserNotice.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\Validity' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Validity.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\netscape_ca_policy_url' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/netscape_ca_policy_url.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\netscape_cert_type' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/netscape_cert_type.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\ASN1\\Maps\\netscape_comment' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/netscape_comment.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\File\\X509' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/File/X509.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\Base' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/Base.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\BuiltIn' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/BuiltIn.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\DefaultEngine' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/DefaultEngine.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\OpenSSL' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/OpenSSL.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\Reductions\\Barrett' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/Reductions/Barrett.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\Reductions\\EvalBarrett' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/Reductions/EvalBarrett.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\Engine' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/Engine.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\GMP' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/GMP.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\GMP\\DefaultEngine' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/GMP/DefaultEngine.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\OpenSSL' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/OpenSSL.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP32' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP32.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP64' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP64.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Base' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Base.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\DefaultEngine' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/DefaultEngine.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Montgomery' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Montgomery.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\OpenSSL' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/OpenSSL.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\Barrett' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/Barrett.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\Classic' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/Classic.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\EvalBarrett' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/EvalBarrett.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\Montgomery' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/Montgomery.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\MontgomeryMult' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/MontgomeryMult.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\PowerOfTwo' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/PowerOfTwo.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BinaryField' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BinaryField.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\BinaryField\\Integer' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/BinaryField/Integer.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\Common\\FiniteField' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/Common/FiniteField.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\Common\\FiniteField\\Integer' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/Common/FiniteField/Integer.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\PrimeField' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/PrimeField.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Math\\PrimeField\\Integer' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Math/PrimeField/Integer.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Net\\SFTP' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Net/SFTP.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Net\\SFTP\\Stream' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Net/SFTP/Stream.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\Net\\SSH2' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/Net/SSH2.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\System\\SSH\\Agent' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/System/SSH/Agent.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\System\\SSH\\Agent\\Identity' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/System/SSH/Agent/Identity.php',
        'WPMailSMTP\\Vendor\\phpseclib3\\System\\SSH\\Common\\Traits\\ReadBytes' => __DIR__ . '/../..' . '/vendor_prefixed/phpseclib/phpseclib/phpseclib/System/SSH/Common/Traits/ReadBytes.php',
        'WPMailSMTP\\WP' => __DIR__ . '/../..' . '/src/WP.php',
        'WPMailSMTP\\WPMailInitiator' => __DIR__ . '/../..' . '/src/WPMailInitiator.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInitbfe762290f8f6a26d6c880a890bad315::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInitbfe762290f8f6a26d6c880a890bad315::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInitbfe762290f8f6a26d6c880a890bad315::$classMap;

        }, null, ClassLoader::class);
    }
}
